@@ -7,8 +7,8 @@ package HTML::Location;
 use strict;
 use UNIVERSAL 'isa';
 use base 'Clone';
-use URI ();
-use File::Spec ();
+use URI              ();
+use File::Spec       ();
 use File::Spec::Unix ();
 
 # Overload stringification to the string form of the URL.
@@ -18,7 +18,7 @@ use overload 'eq'   => '__eq';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.4';
+	$VERSION = '0.5';
 }
 
 
@@ -120,6 +120,11 @@ sub __eq {
 	($left->path eq $right->path) and ($left->uri eq $right->uri);
 }
 
+# Support coercion to a URI via Param::Coerce
+BEGIN {
+	*__as_URI = *URI;
+}
+
 1;
 
 __END__
